# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Social Service."""

__version__ = "1.29.5"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .bulk_create_user_stat_items import BulkCreateUserStatItems
from .bulk_fetch_or_default_s_50dfdc import BulkFetchOrDefaultStatItems
from .bulk_fetch_or_default_s_d6fcc5 import BulkFetchOrDefaultStatItems1
from .bulk_fetch_stat_items import BulkFetchStatItems
from .bulk_fetch_stat_items_1 import BulkFetchStatItems1
from .bulk_inc_user_stat_item import BulkIncUserStatItem
from .bulk_inc_user_stat_item_1 import BulkIncUserStatItem1
from .bulk_inc_user_stat_item_value import BulkIncUserStatItemValue
from .bulk_inc_user_stat_item_b0004a import BulkIncUserStatItemValue1
from .bulk_inc_user_stat_item_0f5ee3 import BulkIncUserStatItemValue2
from .bulk_reset_user_stat_item import BulkResetUserStatItem
from .bulk_reset_user_stat_item_1 import BulkResetUserStatItem1
from .bulk_reset_user_stat_item_2 import BulkResetUserStatItem2
from .bulk_reset_user_stat_item_3 import BulkResetUserStatItem3
from .bulk_reset_user_stat_it_ed9334 import BulkResetUserStatItemValues
from .bulk_update_user_stat_item import BulkUpdateUserStatItem
from .bulk_update_user_stat_item_1 import BulkUpdateUserStatItem1
from .bulk_update_user_stat_item_2 import BulkUpdateUserStatItem2
from .bulk_update_user_stat_item_v2 import BulkUpdateUserStatItemV2
from .create_user_stat_item import CreateUserStatItem
from .delete_user_stat_items import DeleteUserStatItems
from .delete_user_stat_items_1 import DeleteUserStatItems1
from .delete_user_stat_items_2 import DeleteUserStatItems2
from .get_user_stat_items import GetUserStatItems
from .inc_user_stat_item_value import IncUserStatItemValue
from .public_bulk_create_user_ce1688 import PublicBulkCreateUserStatItems
from .public_bulk_inc_user_stat_item import PublicBulkIncUserStatItem
from .public_bulk_inc_user_st_308993 import PublicBulkIncUserStatItem1
from .public_bulk_inc_user_st_374b4e import PublicBulkIncUserStatItemValue
from .public_create_user_stat_item import PublicCreateUserStatItem
from .public_inc_user_stat_item import PublicIncUserStatItem
from .public_inc_user_stat_it_1d89c5 import PublicIncUserStatItemValue
from .public_query_user_stat_items import PublicQueryUserStatItems
from .public_query_user_stat_items_1 import PublicQueryUserStatItems1
from .public_query_user_stat_items_2 import PublicQueryUserStatItems2
from .reset_user_stat_item_value import ResetUserStatItemValue
from .reset_user_stat_item_value_1 import ResetUserStatItemValue1
from .update_user_stat_item_value import UpdateUserStatItemValue
from .update_user_stat_item_value_1 import UpdateUserStatItemValue1
