# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Qo S Manager Service."""

__version__ = ""
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

# admin
from .wrappers import delete_server
from .wrappers import delete_server_async
from .wrappers import set_server_alias
from .wrappers import set_server_alias_async
from .wrappers import update_server_config
from .wrappers import update_server_config_async

# public
from .wrappers import list_server
from .wrappers import list_server_async
from .wrappers import list_server_per_namespace
from .wrappers import list_server_per_namespace_async

# server
from .wrappers import heartbeat
from .wrappers import heartbeat_async
