# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Iam Service."""

__version__ = "5.16.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .add_client_permission import AddClientPermission
from .admin_add_client_permis_b56057 import AdminAddClientPermissionsV3
from .admin_create_client_v3 import AdminCreateClientV3
from .admin_delete_client_per_ccba4f import AdminDeleteClientPermissionV3
from .admin_delete_client_v3 import AdminDeleteClientV3
from .admin_get_clients_by_na_e85014 import AdminGetClientsByNamespaceV3
from .admin_get_clientsby_nam_ac2fda import AdminGetClientsbyNamespacebyIDV3
from .admin_update_client_per_4db324 import AdminUpdateClientPermissionV3
from .admin_update_client_secret_v3 import AdminUpdateClientSecretV3
from .admin_update_client_v3 import AdminUpdateClientV3
from .create_client import CreateClient
from .create_client_by_namespace import CreateClientByNamespace
from .delete_client import DeleteClient
from .delete_client_by_namespace import DeleteClientByNamespace
from .delete_client_permission import DeleteClientPermission
from .get_client import GetClient
from .get_clients import GetClients
from .get_clientsby_namespace import GetClientsbyNamespace
from .update_client import UpdateClient
from .update_client_permission import UpdateClientPermission
from .update_client_secret import UpdateClientSecret
