# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Basic Service."""

__version__ = "2.1.2"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_get_user_profile__eda78b import AdminGetUserProfilePublicInfoByIds
from .create_my_profile import CreateMyProfile
from .delete_user_profile import DeleteUserProfile
from .get_custom_attributes_info import GetCustomAttributesInfo
from .get_my_profile_info import GetMyProfileInfo
from .get_my_zip_code import GetMyZipCode
from .get_private_custom_attr_322032 import GetPrivateCustomAttributesInfo
from .get_user_profile_info import GetUserProfileInfo
from .get_user_profile_info_b_5dfc7f import GetUserProfileInfoByPublicId
from .public_create_user_profile import PublicCreateUserProfile
from .public_get_custom_attri_5323c2 import PublicGetCustomAttributesInfo
from .public_get_user_profile_info import PublicGetUserProfileInfo
from .public_get_user_profile_0d683e import PublicGetUserProfileInfoByPublicId
from .public_get_user_profile_64cc50 import PublicGetUserProfilePublicInfo
from .public_get_user_profile_cdd77a import PublicGetUserProfilePublicInfoByIds
from .public_update_custom_at_7dcf23 import PublicUpdateCustomAttributesPartially
from .public_update_user_profile import PublicUpdateUserProfile
from .public_update_user_prof_c93172 import PublicUpdateUserProfileStatus
from .update_custom_attribute_105f42 import UpdateCustomAttributesPartially
from .update_my_profile import UpdateMyProfile
from .update_my_zip_code import UpdateMyZipCode
from .update_private_custom_a_62b74f import UpdatePrivateCustomAttributesPartially
from .update_user_profile import UpdateUserProfile
from .update_user_profile_status import UpdateUserProfileStatus
